.. _readme:

.. include:: README.rst


Contents
---------

.. toctree::
   :maxdepth: 2

   examples
   sections/environment/index
   sections/microservices/index
   sections/codesign/index
   sections/models/index
   contributing
   sections/about/index


Indices and tables
-------------------
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
